@@ -6,7 +6,6 @@
 
 #pragma once
 
-#include "kcmutils_version.h"
 #include <KCModule>
 
 #include <QVariant>
@@ -20,11 +19,7 @@ class KCMKaddressbookPluginsConfig : public KCModule
 {
     Q_OBJECT
 public:
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    explicit KCMKaddressbookPluginsConfig(QWidget *parent, const QVariantList &args);
-#else
-    explicit KCMKaddressbookPluginsConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
-#endif
+    explicit KCMKaddressbookPluginsConfig(QObject *parent, const KPluginMetaData &data);
     void load() override;
     void save() override;
     void defaults() override;
