@@ -25,12 +25,12 @@ public:
 
     static PluginManager *self();
 
-    Q_REQUIRED_RESULT QVector<Plugin *> pluginsList() const;
+    [[nodiscard]] QList<Plugin *> pluginsList() const;
 
-    Q_REQUIRED_RESULT QVector<PimCommon::PluginUtilData> pluginsDataList() const;
+    [[nodiscard]] QList<PimCommon::PluginUtilData> pluginsDataList() const;
 
-    Q_REQUIRED_RESULT QString configGroupName() const;
-    Q_REQUIRED_RESULT QString configPrefixSettingKey() const;
+    [[nodiscard]] QString configGroupName() const;
+    [[nodiscard]] QString configPrefixSettingKey() const;
     Plugin *pluginFromIdentifier(const QString &id);
 
 private:
