@@ -9,6 +9,7 @@
 #include "mainwindow.h"
 #include "mainwidget.h"
 #include "settings.h"
+#include <KAboutData>
 #include <KActionCollection>
 #include <KConfigGroup>
 #include <KEditToolBar>
@@ -23,17 +24,58 @@
 #include <QFontDatabase>
 #include <QMenuBar>
 #include <QPointer>
+#include <QVBoxLayout>
+
+// signal handler for SIGINT & SIGTERM
+#ifdef Q_OS_UNIX
+#include <KSignalHandler>
+#include <signal.h>
+#include <unistd.h>
+#endif
+
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
 #include <KUserFeedback/NotificationPopup>
 #include <KUserFeedback/Provider>
 #endif
 
+#include <PimCommon/NeedUpdateVersionUtils>
+#include <PimCommon/NeedUpdateVersionWidget>
+
 MainWindow::MainWindow()
     : KXmlGuiWindow(nullptr)
     , mMainWidget(new MainWidget(this, this))
 {
-    setCentralWidget(mMainWidget);
+#ifdef Q_OS_UNIX
+    /**
+     * Set up signal handler for SIGINT and SIGTERM
+     */
+    KSignalHandler::self()->watchSignal(SIGINT);
+    KSignalHandler::self()->watchSignal(SIGTERM);
+    connect(KSignalHandler::self(), &KSignalHandler::signalReceived, this, [this](int signal) {
+        if (signal == SIGINT || signal == SIGTERM) {
+            printf("Shutting down...\n");
+            if (mMainWidget->canClose()) {
+                close();
+            }
+        }
+    });
+#endif
+    auto mainWidget = new QWidget(this);
+    auto mainWidgetLayout = new QVBoxLayout(mainWidget);
+    mainWidgetLayout->setContentsMargins({});
+    mainWidgetLayout->setSpacing(0);
+    if (PimCommon::NeedUpdateVersionUtils::checkVersion()) {
+        const auto status = PimCommon::NeedUpdateVersionUtils::obsoleteVersionStatus(KAboutData::applicationData().version(), QDate::currentDate());
+        if (status != PimCommon::NeedUpdateVersionUtils::ObsoleteVersion::NotObsoleteYet) {
+            auto needUpdateVersionWidget = new PimCommon::NeedUpdateVersionWidget(this);
+            mainWidgetLayout->addWidget(needUpdateVersionWidget);
+            needUpdateVersionWidget->setObsoleteVersion(status);
+        }
+    }
+    mainWidgetLayout->addWidget(mMainWidget);
+
+    setCentralWidget(mainWidget);
 
     setStandardToolBarMenuEnabled(true);
 
